# Changelog
All notable changes to sced-matcher will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [0.2.0] - 2025-11-27
- Bundled SCED data with package (SCED version v12).

## [0.1.3] - 2025-09-11
- added dynamic link to data source

## [0.1.2] - 2025-09-10
- removed old OpenAI based implementation
- added Google Gemini implementation (more robust)

## [0.1.1] - 2025-09-08
- added compatibility with OpenAI
- added ability to match on single column table inputs